Exception: Anydoc::Error

Inherits:
StandardError
  • Object
show all
Defined in:
lib/anydoc/errors.rb,
sig/anydoc.rbs

Overview

Base class for everything this gem raises. Unreadable files raise the Errno exception any other read of them would, and a format argument naming no supported format raises ArgumentError.

Direct Known Subclasses

ConvertError