Class: Anydoc::ListItem

Inherits:
Data
  • Object
show all
Defined in:
lib/anydoc/document.rb,
sig/anydoc.rbs

Overview

One item of a List.

Instance Attribute Summary collapse

Instance Attribute Details

#blocksArray<Block> (readonly)

Returns:



151
152
# File 'lib/anydoc/document.rb', line 151

class ListItem < Data.define(:blocks, :checked, :marker_label)
end

#checkedBoolean? (readonly)

Returns task-list state, when the item carries a checkbox.

Returns:

  • (Boolean, nil)

    task-list state, when the item carries a checkbox.



151
152
# File 'lib/anydoc/document.rb', line 151

class ListItem < Data.define(:blocks, :checked, :marker_label)
end

#marker_labelString? (readonly)

Returns literal marker text that overrides the list marker when the source number text cannot be reproduced from the marker and position alone (composite number text such as 1-a)).

Returns:

  • (String, nil)

    literal marker text that overrides the list marker when the source number text cannot be reproduced from the marker and position alone (composite number text such as 1-a)).



151
152
# File 'lib/anydoc/document.rb', line 151

class ListItem < Data.define(:blocks, :checked, :marker_label)
end