Class: Anydoc::ListItem
- Inherits:
-
Data
- Object
- Data
- Anydoc::ListItem
- Defined in:
- lib/anydoc/document.rb,
sig/anydoc.rbs
Overview
One item of a List.
Instance Attribute Summary collapse
- #blocks ⇒ Array<Block> readonly
-
#checked ⇒ Boolean?
readonly
Task-list state, when the item carries a checkbox.
-
#marker_label ⇒ String?
readonly
Literal marker text that overrides the list marker when the source number text cannot be reproduced from the marker and position alone (composite number text such as
1-a)).
Instance Attribute Details
#blocks ⇒ Array<Block> (readonly)
151 152 |
# File 'lib/anydoc/document.rb', line 151 class ListItem < Data.define(:blocks, :checked, :marker_label) end |
#checked ⇒ Boolean? (readonly)
Returns task-list state, when the item carries a checkbox.
151 152 |
# File 'lib/anydoc/document.rb', line 151 class ListItem < Data.define(:blocks, :checked, :marker_label) end |
#marker_label ⇒ String? (readonly)
Returns literal marker text that overrides the list marker
when the source number text cannot be reproduced from the marker and
position alone (composite number text such as 1-a)).
151 152 |
# File 'lib/anydoc/document.rb', line 151 class ListItem < Data.define(:blocks, :checked, :marker_label) end |